@@ -11,7 +11,7 @@ import urllib
 import click
 from betterboto import client as betterboto_client
 
-from servicecatalog_puppet import aws, config, constants, serialisation_utils
+from servicecatalog_puppet import aws, config, constants
 
 
 logger = logging.getLogger(constants.PUPPET_LOGGER_NAME)
