@@ -7,7 +7,7 @@ import click
 import terminaltables
 from betterboto import client as betterboto_client
 
-from servicecatalog_puppet import constants, serialisation_utils, utils
+from servicecatalog_puppet import constants, utils
 
 
 result_look_up = dict(Failed="red", Succeeded="green")
