@@ -116,13 +116,9 @@ def get_should_forward_failures_to_opscenter(puppet_account_id, default_region=N
 
 
 @functools.lru_cache(maxsize=32)
-def get_task_idempotency_token(puppet_account_id, default_region=None):
-    logger.info(
-        "getting task_idempotency_token,  default_region: {}".format(default_region)
-    )
-    return get_config(puppet_account_id, default_region).get(
-        "task_idempotency_token", None
-    )
+def get_drift_token(puppet_account_id, default_region=None):
+    logger.info("getting drift_token,  default_region: {}".format(default_region))
+    return get_config(puppet_account_id, default_region).get("drift_token", None)
 
 
 @functools.lru_cache(maxsize=32)
