@@ -3,6 +3,7 @@ import time
 import traceback
 
 from servicecatalog_puppet import serialisation_utils
+from servicecatalog_puppet.serialisation_utils import unwrap
 from servicecatalog_puppet.waluigi.constants import COMPLETED, ERRORED
 from servicecatalog_puppet.waluigi.dag_utils import logger
 from servicecatalog_puppet.waluigi.locks.external import (
@@ -11,7 +12,6 @@ from servicecatalog_puppet.waluigi.locks.external import (
     unlock_resources_for_task,
 )
 from servicecatalog_puppet.workflow.dependencies import task_factory
-from servicecatalog_puppet.workflow.tasks import unwrap
 
 
 def worker_task(
