@@ -15,7 +15,7 @@ class GetOrCreateOrganizationalUnitTask(tasks.TaskWithReference):
     name = luigi.Parameter()
     tags = luigi.ListParameter()
     parent_ou_task_ref = luigi.Parameter()
-    cachable_level = constants.CACHE_LEVEL_NORMAL
+    cachable_level = constants.CACHE_LEVEL_RUN
 
     def params_for_results_display(self):
         return {
