@@ -15,7 +15,7 @@ class ImportIntoSpokeLocalPortfolioTask(tasks.TaskWithReference):
 
     portfolio_get_all_products_and_their_versions_ref = luigi.Parameter()
     portfolio_get_all_products_and_their_versions_for_hub_ref = luigi.Parameter()
-    cachable_level = constants.CACHE_LEVEL_NORMAL
+    cachable_level = constants.CACHE_LEVEL_RUN
 
     def params_for_results_display(self):
         return {
